@@ -1,9 +1,11 @@
 package DateTime::Fiction::JRRTolkien::Shire;
 
+use 5.008004;
+
 use vars qw($VERSION);
 use strict;
-use DateTime;
-our $VERSION = 0.02;
+use DateTime 0.14;
+our $VERSION = '0.20';
 
 # This assumes all the values in the info hashref are valid, and doesn't do validation
 # However, the day and month parameters will be given defaults if not present
@@ -554,7 +556,7 @@ sub on_date {
     # the day matches up
     $events{0} = { 3  => "Wedding of King Elessar and Arwen, 1419.\n"
 		   };
-    $events{1} = { 8  => "The Company of the Ring reaches Holland, 1419.\n",
+    $events{1} = { 8  => "The Company of the Ring reaches Hollin, 1419.\n",
 		   13 => "The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.\n",
 		   14 => "The Company of the Ring spends the night in Moria hall 21, 1419.\n",
 		   15 => "The Bridge of Khazad-dum, and the fall of Gandalf, 1419.\n",
@@ -576,7 +578,7 @@ sub on_date {
 		       "Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.\n" .
 		       "Frodo and Samwise enter the eastern Emyn Muil, 1419.\n",
 		   27 => "Aragorn reaches the west-cliff at sunrise, 1419.\n" .
-		       "Eomer sets out Eastfold against Theoden's orders to pursue the Orcs, 1419.\n",
+		       "Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.\n",
 		   28 => "Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.\n",
 		   29 => "Meriodoc and Pippin escape and meet Treebeard, 1419.\n" .
 		       "The Rohirrim attack at sunrise and destroy the Orcs, 1419.\n" .
@@ -610,7 +612,7 @@ sub on_date {
 		   11 => "Gollum visits Shelob, 1419.\n" . 
 		       "Denethor sends Faramir to Osgiliath, 1419.\n" .
 		       "Eastern Rohan is invaded and Lorien assaulted, 1419.\n",
-		   12 => "Gollum leads Frodo in Shelob's lair, 1419.\n" .
+		   12 => "Gollum leads Frodo into Shelob's lair, 1419.\n" .
 		       "Ents defeat the invaders of Rohan, 1419.\n",
 		   13 => "Frodo captured by the Orcs of Cirith Ungol, 1419.\n" .
 		       "The Pelennor is overrun and Faramir is wounded, 1419.\n" .
@@ -637,7 +639,7 @@ sub on_date {
 		   27 => "Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.\n",
 		   28 => "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n"
 		   };
-    $events{4} = { 6  => "The mallorn trea flowers in the party field, 1420.\n",
+    $events{4} = { 6  => "The mallorn tree flowers in the party field, 1420.\n",
 	           8  => "Ring bearers are honored on the fields of Cormallen, 1419.\n",
 	           12 => "Gandalf arrives in Hobbiton, 1418\n"
 	           };
@@ -654,7 +656,7 @@ sub on_date {
     $events{8} = { 10 => "Funeral of King Theoden, 1419.\n"
 		   };
     $events{9} = { 18 => "Gandalf escapes from Orthanc in the early hours, 1418.\n",
-		   19 => "Gandalf comes to Edoras as a beggar, and is refused admintance, 1418",
+		   19 => "Gandalf comes to Edoras as a beggar, and is refused admittance, 1418",
 		   20 => "Gandalf gains entrance to Edoras.  Theoden commands him to go:\n" .
 		       "\"Take any horse, only be gone ere tomorrow is old\", 1418.\n",
 		   21 => "The hobbits return to Rivendell, 1419.\n",
@@ -663,7 +665,7 @@ sub on_date {
 		       "  they drive off the guard of Rangers, 1418.\n" .
 		       "Saruman comes to the Shire, 1419.\n",   
 		   23 => "Four Black Riders enter the shire before dawn.  The others pursue \n" .
-		       "the Rangers eastword and then return to watch the Greenway, 1418.\n" .
+		       "the Rangers eastward and then return to watch the Greenway, 1418.\n" .
 		       "A Black Rider comes to Hobbiton at nightfall, 1418.\n" . 
 		       "Frodo leaves Bag End, 1418.\n" .
 		       "Gandalf having tamed Shadowfax rides from Rohan, 1418.\n",
@@ -677,7 +679,7 @@ sub on_date {
             	   };
     $events{10} = { 3  => "Gandalf attacked at night on Weathertop, 1418.\n",
 		    5  => "Gandalf and the Hobbits leave Rivendell, 1419.\n",
-		    6  => "The camp under weathertop is attacked at night and Frodo is wounded, 1418.\n",
+		    6  => "The camp under Weathertop is attacked at night and Frodo is wounded, 1418.\n",
 		    11 => "Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.\n",
 		    13 => "Frodo crosses the Bridge of Mitheithel, 1418.\n",
 		    18 => "Glorfindel finds Frodo at dusk, 1418.\n" . 
@@ -691,7 +693,7 @@ sub on_date {
     $events{11} = { 3  => "Battle of Bywater and passing of Saruman, 1419.\n" .
 			"End of the War of the Ring, 1419.\n"
 		  };
-    $events{12} = { 25 => "The Company of the Ring leaves Rivendell at dusk.\n"
+    $events{12} = { 25 => "The Company of the Ring leaves Rivendell at dusk, 1418.\n"
 		    };
 
     if ($self->{holiday} and defined($events{0}->{$self->{holiday}})) {
@@ -791,10 +793,10 @@ being lost.  The same is true of time zones.
 Most of these methods mimic their corresponding DateTime methods in functionality.
 For additional information on these methods, see the DateTime documentation.
 
-=over 4
-
 =head2 Constructors
 
+=over
+
 =item * new( ... )
 
 This method takes a year, month, and day parameter, or a year and holiday parameter.
@@ -855,8 +857,12 @@ like in new.
 Creates a new Shire object that is the same date (and underlying time)
 as the calling object.
 
+=back
+
 =head2 Get Methods
 
+=over
+
 =item * year
 
 returns the year.
@@ -964,8 +970,12 @@ This can be fun to put in a .bashrc or .cshrc.  Try
     perl -MDateTime::Fiction::JRRTolkien::Shire 
       -le 'print DateTime::Fiction::JRRTolkien::Shire->now->on_date;'
 
+=back
+
 =head2 Set Methods
 
+=over
+
 =item * Set( ... )
 
 Allows the day, month, and year to be changed.  It takes any parameters allowed
@@ -993,14 +1003,14 @@ DateTime object.
 Just like in DateTime.  This method has no effect on the shire calendar, but be
 stored with the date if it is ever converted to another calendar with time support.
 
+=back
+
 =head2 Comparisons and Stringification
 
 All comparison operators should work, just as in DateTime.  In addition,
 all DateTime::Fiction::JRRTolkien::Shire objects will interpolate into
 a string representing the date when used in a double-quoted string.  
 
-=back
-
 =head1 DURATIONS AND DATE MATH
 
 Durations and date math (other than comparisons) are not supported at present
@@ -1012,7 +1022,7 @@ the DateTime class, and then the DateTime object converted back to a Shire objec
 
 =head1 NOTE: YEAR CALCULATION
 
-http://www.glyhweb.com/arda/f/fourthage.html references a letter sent by
+L<http://www.glyhweb.com/arda/f/fourthage.html> references a letter sent by
 Tolkien in 1958 in which he estimates approxiimately 6000 years have passed
 since the War of the Ring and the end of the Third Age.  (Thanks to Danny
 O'Brien from sending me this link).  I took this approximate as an exact amount
@@ -1041,19 +1051,26 @@ of days regardless of years.  However, the variations follow a 400 year cycle.
 
 Tom Braun <tbraun@pobox.com>
 
-=head1 LICENSE AND COPYRIGHT
+Thomas R. Wyant, III F<wyant at cpan dot org>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2003 Tom Braun. All rights reserved.
+
+Copyright (C) 2017 Thomas R. Wyant, III
 
-Copyright (c) 2003 Tom Braun.  All rights reserved.  This program is
-free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.
-                                                                                
 The calendar implemented on this module was created by J.R.R. Tolkien,
-and the copyright is still held by his estate.  The license and 
-copyright given herein applies only to this code and not to the 
+and the copyright is still held by his estate.  The license and
+copyright given herein applies only to this code and not to the
 calendar itself.
-                                                                   
-The full text of the license can be found in the LICENSE file included
-with this module.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. For more details, see the full text
+of the licenses in the LICENSES directory included with this module.
+
+This program is distributed in the hope that it will be useful, but
+without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =head1 SUPPORT
 
@@ -1063,16 +1080,18 @@ support on them, please see the support options in the DateTime documentation.
 
 =head1 BIBLIOGRAPHY
 
-Tolkien, J. R. R. <i>Return of the King<i>.  New York: Houghton Mifflin Press,
+Tolkien, J. R. R. I<Return of the King>.  New York: Houghton Mifflin Press,
 1955.
 
-http://www.glyphweb.com/arda/f/fourthage.html
+L<http://www.glyphweb.com/arda/f/fourthage.html>
 
 =head1 SEE ALSO
 
 The DateTime project documentation (perldoc DateTime, datetime@perl.org mailing list,
-or http://datetime.perl.org/).
+or L<http://datetime.perl.org/>).
 
 =cut
 
 1;
+
+# ex: set textwidth=72 :
